#!/bin/sh
# Date: 07.07.07

# Arguments:
#   $1      a squeak image (not the spoon image)
#   $2      the path to the spoon installation. If omitted ./spoon
#           is assumed

if [ "$1" = "" ];
then
   echo "usage: $0 <squeak.image> [spoon install dir]"
   exit
fi
SQUEAK_IMAGE=$1

SCRIPT_PATH=`dirname $0`
SPOON_PATH="$SCRIPT_PATH/spoon/components"
if [ "$2" != "" ];
then
   SPOON_PATH=$2
fi

# need for loading libraries like Flow
export LD_LIBRARY_PATH=$SPOON_PATH

# determine if the bootstrap script should be loaded
RUN_MODE=`basename $0 .sh`

INIT_SCRIPT=""
if [ "$RUN_MODE" = "bootstrap" ];
then
   INIT_SCRIPT="$PWD/$SCRIPT_PATH/bootstrap.st"
echo $INIT_SCRIPT
fi

# start the spoon memory image
$SPOON_PATH/processor $SPOON_PATH/memory.image &

# remember the instance running in the background and stop
# it if the image running in the foreground is stopped.
SPOONPID=$!
trap 'kill -15 $SPOONPID; exit' EXIT HUP INT QUIT TERM

# finally start the image
squeak $SQUEAK_IMAGE "$INIT_SCRIPT" $*
